==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/SecureStringArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.SecureStringArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Azure Synapse secure string definition. The string value will be masked with asterisks '*' during Get or List API calls.
 * @property type Type of the secret.
 * Expected value is 'SecureString'.
 * @property value Value of secure string.
 */
public data class SecureStringArgs(
    public val type: Output<String>,
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.SecureStringArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.SecureStringArgs =
        com.pulumi.azurenative.synapse.inputs.SecureStringArgs.builder()
            .type(type.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SecureStringArgs].
 */
@PulumiTagMarker
public class SecureStringArgsBuilder internal constructor() {
    private var type: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Type of the secret.
     * Expected value is 'SecureString'.
     */
    @JvmName("njgixkdubgrhorch")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Value of secure string.
     */
    @JvmName("iwuwimuvmrcwiegn")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Type of the secret.
     * Expected value is 'SecureString'.
     */
    @JvmName("pswdohinfnqbdgru")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Value of secure string.
     */
    @JvmName("aecjjmcefihtspla")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): SecureStringArgs = SecureStringArgs(
        type = type ?: throw PulumiNullFieldException("type"),
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/SecureStringArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.SecureStringArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Azure Synapse secure string definition. The string value will be masked with asterisks '*' during Get or List API calls.
 * @property type Type of the secret.
 * Expected value is 'SecureString'.
 * @property value Value of secure string.
 */
public data class SecureStringArgs(
    public val type: Output<String>,
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.SecureStringArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.SecureStringArgs =
        com.pulumi.azurenative.synapse.inputs.SecureStringArgs.builder()
            .type(type.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SecureStringArgs].
 */
@PulumiTagMarker
public class SecureStringArgsBuilder internal constructor() {
    private var type: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Type of the secret.
     * Expected value is 'SecureString'.
     */
    @JvmName("bwkoweuubbpolgrc")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Value of secure string.
     */
    @JvmName("hanmajcdkrccxkgd")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Type of the secret.
     * Expected value is 'SecureString'.
     */
    @JvmName("sxqyykkydpaxeigp")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Value of secure string.
     */
    @JvmName("tcdtcaxkvvdxkpvs")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): SecureStringArgs = SecureStringArgs(
        type = type ?: throw PulumiNullFieldException("type"),
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}
